@@ -40,10 +40,6 @@ struct fields {
         jclass clazz;
         jfieldID descriptorID;
     } FileDescriptor;
-    struct {
-        jclass clazz;
-        jmethodID onNativeCrashID;
-    } LibVLC;
     struct {
         jclass clazz;
         jfieldID mInstanceID;
@@ -66,6 +62,7 @@ struct fields {
         jmethodID createSubtitleTrackFromNativeID;
         jmethodID createUnknownTrackFromNativeID;
         jmethodID createSlaveFromNativeID;
+        jmethodID createStatsFromNativeID;
     } Media;
     struct {
         struct {
