@@ -251,10 +251,6 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
                 if (mPlaybackController != null)
                     mPlaybackController.showSubsDelaySetting();
                 break;
-            case ACTION_PLAYBACK_SPEED:
-                if (mPlaybackController != null)
-                    mPlaybackController.showPlaybackSpeedSetting();
-                break;
             default:
                 return;
         }
@@ -475,7 +471,7 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
                 ((VideoPlayerActivity)getActivity()).switchToAudioMode(true);
                 break;
             case ID_POPUP_VIDEO:
-                if (VLCApplication.showTvUi()) {
+                if (AndroidUtil.isOOrLater || VLCApplication.showTvUi()) {
                     getActivity().enterPictureInPictureMode();
                 } else {
                     if (Permissions.canDrawOverlays(mActivity))
